<?php
/**
 * Theme Customizer
 *
 * @package WordPress
 * @subpackage Stix
 * @since 1.0.8
 * @version 1.0.8
 */

if ( ! function_exists( 'stix_customize_register' ) ) {
	/**
	 * Customizer register.
	 *
	 * @param array $wp_customize Main class that makes it all work..
	 */
	function stix_customize_register( $wp_customize ) {
		$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
		$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
		$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

		/**
		 * Add section for use by theme settings
		 */
		$wp_customize->add_section(
			'stix_options_section',
			array(
				'title'    => __( 'Theme Options', 'stix' ),
				'priority' => 35,
			)
		);
		$wp_customize->add_setting(
			'stix_search_header_setting',
			array(
				'default'           => 'yes',
				'transport'         => 'refresh',
				'sanitize_callback' => 'stix_radio_text_sanitization',
			)
		);
		$wp_customize->add_control(
			new stix_Text_Radio_Button_Control(
				$wp_customize,
				'stix_search_header',
				array(
					'settings' => 'stix_search_header_setting',
					'section'  => 'stix_options_section',
					'type'     => 'text_radio_button',
					'label'    => __( 'Add Search Form to Header', 'stix' ),
					'choices'  => array(
						'yes' => __( 'Yes', 'stix' ),
						'no'  => __( 'No', 'stix' ),
					),
				)
			)
		);
		$wp_customize->add_setting(
			'stix_sidebar_position_setting',
			array(
				'default'           => 'none',
				'transport'         => 'refresh',
				'sanitize_callback' => 'stix_radio_text_sanitization',
			)
		);
		$wp_customize->add_control(
			new stix_Text_Radio_Button_Control(
				$wp_customize,
				'stix_sidebar_position',
				array(
					'settings' => 'stix_sidebar_position_setting',
					'section'  => 'stix_options_section',
					'type'     => 'text_radio_button',
					'label'    => __( 'Sidebar Position', 'stix' ),
					'choices'  => array(
						'none'  => __( 'None', 'stix' ),
						'left'  => __( 'Left', 'stix' ),
						'right' => __( 'Right', 'stix' ),
					),
				)
			)
		);
		$wp_customize->add_setting(
			'stix_post_content_setting',
			array(
				'default'           => 'excerpt',
				'transport'         => 'refresh',
				'sanitize_callback' => 'stix_radio_text_sanitization',
			)
		);
		$wp_customize->add_control(
			new stix_Text_Radio_Button_Control(
				$wp_customize,
				'stix_post_content',
				array(
					'settings' => 'stix_post_content_setting',
					'section'  => 'stix_options_section',
					'type'     => 'text_radio_button',
					'label'    => __( 'Post Content on Archive Pages', 'stix' ),
					'choices'  => array(
						'excerpt' => __( 'Excerpt', 'stix' ),
						'more'    => __( 'More Link', 'stix' ),
					),
				)
			)
		);
		$wp_customize->add_setting(
			'stix_pagination_navigation_setting',
			array(
				'default'           => 'pagination',
				'transport'         => 'refresh',
				'sanitize_callback' => 'stix_radio_text_sanitization',
			)
		);
		$wp_customize->add_control(
			new stix_Text_Radio_Button_Control(
				$wp_customize,
				'stix_pagination_navigation',
				array(
					'settings' => 'stix_pagination_navigation_setting',
					'section'  => 'stix_options_section',
					'type'     => 'text_radio_button',
					'label'    => __( 'Posts Navigation', 'stix' ),
					'choices'  => array(
						'pagination' => __( 'Pagination', 'stix' ),
						'navigation' => __( 'Navigation', 'stix' ),
					),
				)
			)
		);
	}
	add_action( 'customize_register', 'stix_customize_register' );
}

/**
 * Sanitize Callbacks
 */
if ( ! function_exists( 'stix_text_sanitization' ) ) {
	/**
	 * Radio Text sanitization.
	 *
	 * @param  string $input Text to be sanitized.
	 * @return string $input Sanitized text.
	 */
	function stix_radio_text_sanitization( $input ) {

		if ( strpos( $input, ',' ) !== false ) {
			$input = explode( ',', $input );
		}
		if ( is_array( $input ) ) {
			foreach ( $input as $key => $value ) {
				$input[ $key ] = sanitize_text_field( $value );
			}
			$input = implode( ',', $input );
		} else {
			$input = sanitize_text_field( $input );
		}

		return $input;

	}
}

/**
 * Binds JS handler to make Theme Customizer preview reload changes asynchronously.
 */
function stix_customizer_preview() {
	wp_enqueue_script( 'stix-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'jquery' ), '1.0.8', true );
}
add_action( 'customize_preview_init', 'stix_customizer_preview' );

/**
 * Custom Control Styling.
 */
function stix_customizer_custom_control_css() {
	?>

	<style>

		.text_radio_button_control:after {
			content: " ";
			display: block;
			clear: both;
		}

		.text_radio_button_control .radio-buttons {
			display: inline-block;
			border: 1px solid #f9f9fe;
		}

		.text_radio_button_control .radio-button-label {
			cursor: pointer;
			float: left;
		}

		.text_radio_button_control .radio-button-label > input {
			display: none;
		}

		.text_radio_button_control .radio-button-label span {
			cursor: pointer;
			font-weight: 500;
			border: 2px solid #f9f9fe;
			margin: 0;
			background-color: #eee;
			padding: 5px 15px 5px 15px;
			display: inline-block;
		}

		.text_radio_button_control .radio-button-label span:hover {
			background-color: rgba(255, 255, 255, .2);
			color: #2885bb;
		}

		.text_radio_button_control .radio-button-label > input:checked + span {
			background-color: #2084bd;
			color: #fff;
		}

		.text_radio_button_control .radio-button-label > input:checked + span:hover {
			color: #fff;
		}

	</style>
	<?php
}
add_action( 'customize_controls_print_styles', 'stix_customizer_custom_control_css' );
